# CATNIP

**C**limate **A**nalysis **T**ools: **N**ow **I**n **P**ython

This library is a collection of routines to make frequently used climate data analysis
and visualisation tasks in Iris easier and quicker to write.

Complete documentation can be found at: [CATNIP Docs](https://metoffice.github.io/CATNIP/)
